@@ -341,20 +341,24 @@ void	*CallChain::get_root()
 	return root;
 }
 
-char	*CallChain::get_text(void *node)
+char *CallChain::get_text(void *node)
 {
 	static char stupid[1024]; // FIXME: static var
-	char *s = stupid;
-	CallChainNode *n=(CallChainNode*)node;
+	CallChainNode *n = (CallChainNode*)node;
 	int d = 0;
 	n->xa->difference(d, n->faddr->addr);
 	char sign = '+';
-	if (d<0) {
+	if (d < 0) {
 		d = -d;
 		sign = '-';          
 	}
 	global_analyser_address_string_format = ADDRESS_STRING_FORMAT_COMPACT | ADDRESS_STRING_FORMAT_ADD_0X;
-	s+=ht_snprintf(stupid, sizeof stupid, "%s%c%x (%y)", n->faddr->label?n->faddr->label->name:"unknown", sign, d, n->xa);
+	ht_snprintf(stupid, sizeof stupid, "%s%c%x (%y)", 
+		n->faddr->label ? n->faddr->label->name : "unknown", 
+		sign, 
+		d, 
+		n->xa
+	);
 	return stupid;
 }
 
@@ -565,7 +569,7 @@ bool ht_aviewer::pos_to_string(viewer_pos p, char *result, int maxlen)
 bool ht_aviewer::convertViewerPosToAddress(const viewer_pos &p, Address **a)
 {
 	*a = analy->createAddress();
-	(*a)->getFromArray((byte*)&(p.u.line_id.id2));
+	(*a)->getFromUInt64((uint64(p.u.line_id.id1) << 32) + p.u.line_id.id2);
 	return true;
 }
 
@@ -574,8 +578,11 @@ bool ht_aviewer::convertAddressToViewerPos(Address *a, viewer_pos *p)
 	if (a && a->isValid()) {
 		clear_viewer_pos(p);
 		p->u.sub = analy_sub;
-		a->putIntoArray((byte*)&(p->u.line_id.id2));
-		p->u.line_id.id1 = 0;
+		uint64 u;
+		a->putIntoUInt64(u);
+		p->u.line_id.id1 = u >> 32;
+		p->u.line_id.id2 = u;
+		p->u.line_id.id3 = 0;
 		return true;
 	} else {
 		return false;
@@ -679,7 +686,7 @@ static int ht_aviewer_symbol_to_addr(void *Aviewer, const char *s, uint64 &v)
 		return false;
 	} else if (strcmp(s, "&") ==0) {
 		if (aviewer->getCurrentAddress(&a)) {
-			a->putIntoArray((byte*)&v);
+			a->putIntoUInt64(v);
 			delete a;
 			return true;
 		} else {
@@ -741,9 +748,10 @@ void ht_aviewer::generateOutputDialog()
 	NEW_OBJECT(v2, ht_label, &b, "output ~filename:", v1);
 	dialog->insert(v2);
 
-	String filename, basename, suffix;
+	String filename, basename, basename2, suffix;
 	file->getFilename(filename);
-	filename.rightSplit('.', basename, suffix);
+	filename.rightSplit('/', suffix, basename2);
+	basename2.rightSplit('.', basename, suffix);
 	basename += ".out";
 	setdatastr(v1, basename.contentChar());
 
@@ -796,20 +804,22 @@ void ht_aviewer::generateOutputDialog()
 		getdatastr(&odd.id1, filename);
 		getdatastr(&odd.id2, start_str);
 		getdatastr(&odd.id3, end_str);
-		if (!string_to_pos(start_str, &start)) {
-			errorbox(globalerror);
-			continue;
+		if (start_str[0] == 0) {
+			convertAddressToViewerPos(analy_sub->lowestaddress, &start);
+		} else {
+			if (!string_to_pos(start_str, &start)) {
+				errorbox(globalerror);
+				continue;
+			}
 		}
-/*		uint64 end_by_lines;
-		if ((by_lines = end_str[0]=='#')) {
-			char *pend = &end_str[1];
-			parseIntStr(pend, end_by_lines, 10);
-		} else {*/
+		if (end_str[0] == 0) {
+			convertAddressToViewerPos(analy_sub->highestaddress, &end);
+		} else {
 			if (!string_to_pos(end_str, &end)) {
 				errorbox(globalerror);
 				continue;
 			}
-//		}
+		}
 		Address *start_addr, *end_addr;
 		if (!convertViewerPosToAddress(start, &start_addr) || !convertViewerPosToAddress(end, &end_addr)) {
 			errorbox("invalid address");
@@ -903,7 +913,7 @@ void ht_aviewer::dataStringDialog()
 		if (bz > 2) {
 			analy_string *str = string_test(buffer, bz);
 			if (str) {
-				char string1[256], string2[31];
+				char string1[128], string2[128];
 				str->render_string(string2, sizeof string2);
 				ht_snprintf(string1, sizeof string1, "%s_%s", str->name(), string2);
 				make_valid_name(string2, string1);
@@ -1022,6 +1032,12 @@ bool ht_aviewer::get_hscrollbar_pos(int *pstart, int *psize)
 	return false;
 }
 
+void ht_aviewer::getminbounds(int *width, int *height)
+{
+	*width = 25;
+	*height = 4;
+}
+
 int ht_aviewer::get_pindicator_str(char *buf, int max_len)
 {
 	Address *addr;
@@ -1062,10 +1078,10 @@ void ht_aviewer::handlemsg(htmsg *msg)
 		m->insert_separator();
 		ht_static_context_menu *sub=new ht_static_context_menu();
 		sub->init("~Control");
-		sub->insert_entry("~Information...", 0, cmd_analyser_info, 0, 1);
+		sub->insert_entry("~Information...", NULL, cmd_analyser_info, 0, 1);
 		sub->insert_separator();
-		sub->insert_entry("~Save state", 0, cmd_analyser_save, 0, 1);
-		sub->insert_entry("~Export to file...", NULL, cmd_analyser_generate_output, 0, 1);
+		sub->insert_entry("~Save state", NULL, cmd_analyser_save, 0, 1);
+		sub->insert_entry("~Export to file...", "Ctrl-O", cmd_analyser_generate_output, K_Control_O, 1);
 		sub->insert_separator();
 		sub->insert_entry("~Continue at address", "c", cmd_analyser_continue, 0, 1);
 		sub->insert_entry("~Pause / resume", "p", cmd_analyser_pause_resume, 0, 1);
@@ -1109,10 +1125,6 @@ void ht_aviewer::handlemsg(htmsg *msg)
 			sendmsg(cmd_analyser_this_function);
 			clearmsg(msg);
 			return;
-		case K_Control_O:
-			sendmsg(cmd_analyser_generate_output);
-			clearmsg(msg);
-			return;
 		case 'c':
 			if (cursor_tag_class == tag_class_sel) {
 				sendmsg(cmd_analyser_continue);
@@ -1265,7 +1277,7 @@ void ht_aviewer::handlemsg(htmsg *msg)
 		}
 		global_analyser_address_string_format = ADDRESS_STRING_FORMAT_LEADING_ZEROS;
 		if (analy->validAddress(addr, scvalid)) {
-			char n[255];
+			char n[256];
 			char str[1024];
 			Symbol *l = analy->getSymbolByAddress(addr);
 			if (l) ht_strlcpy(n, l->name, sizeof n); else n[0] = 0;
@@ -1287,9 +1299,7 @@ void ht_aviewer::handlemsg(htmsg *msg)
 					} else {
 						global_analyser_address_string_format = ADDRESS_STRING_FORMAT_LEADING_ZEROS;
 						if (confirmbox("'%s' is an invalid label name.\nMake valid?", n)==button_yes) {
-							char n2[255];
-							make_valid_name(n2, n);
-							strcpy(n, n2);
+							make_valid_name(n, n);
 						}
 					}
 				} else {
@@ -1462,12 +1472,12 @@ void ht_aviewer::handlemsg(htmsg *msg)
 		return;
 	}*/
 	case msg_get_analyser: {
-		msg->msg=msg_retval;
-		msg->data1.ptr=analy;
+		msg->msg = msg_retval;
+		msg->data1.ptr = analy;
 		return;
 	}
 	case msg_set_analyser: {
-		Analyser *a=(Analyser*)msg->data1.ptr;
+		Analyser *a = (Analyser*)msg->data1.ptr;
 		if (analy) {
 			analy->done();
 			delete analy;
@@ -1547,7 +1557,7 @@ bool ht_aviewer::ref_sel(LINE_ID *id)
 	case 0:
 		if (analy) {
 			Address *a = analy->createAddress();
-			a->getFromArray((byte*)&id->id1);
+			a->getFromUInt64((uint64(id->id1) << 32) + id->id2);
 			bool res = gotoAddress(a, this);
 			delete a;
 			return res;
@@ -1557,7 +1567,7 @@ bool ht_aviewer::ref_sel(LINE_ID *id)
 	case 1:
 		if (analy) {
 			Address *a = analy->createAddress();
-			a->getFromArray((byte*)&id->id1);
+			a->getFromUInt64((uint64(id->id1) << 32) + id->id2);
 			showXRefs(a);
 			delete a;
 		}
@@ -1578,7 +1588,7 @@ void ht_aviewer::searchForXRefs(Address *Addr)
 	char str[100];
 	global_analyser_address_string_format = ADDRESS_STRING_FORMAT_COMPACT;
 	ht_snprintf(str, sizeof str, "%y", Addr);
-	ht_regex_search_request *q=new ht_regex_search_request(SC_VISUAL, SF_REGEX_CASEINSENSITIVE, str);
+	ht_regex_search_request *q = new ht_regex_search_request(SC_VISUAL, SF_REGEX_CASEINSENSITIVE, str);
 	viewer_pos vp_start, vp_end;
 	convertAddressToViewerPos(analy_sub->lowestaddress, &vp_start);
 	convertAddressToViewerPos(analy_sub->highestaddress, &vp_end);
@@ -1946,7 +1956,7 @@ bool ht_aviewer::symbol_handler(eval_scalar *result, char *name)
 			}
 			convertViewerPosToAddress(vp, &w);
 			uint64 b = 0;
-			w->putIntoArray((byte*)&b);
+			w->putIntoUInt64(b);
 			delete w;
 			scalar_create_int_q(result, b);
 			return true;
@@ -1956,7 +1966,7 @@ bool ht_aviewer::symbol_handler(eval_scalar *result, char *name)
 		if (strcmp(name, "$")==0) {
 			if (getCurrentAddress(&w)) {
 				uint64 b = 0;
-				w->putIntoArray((byte*)&b);
+				w->putIntoUInt64(b);
 				scalar_create_int_q(result, b);
 				delete w;
 				return true;
@@ -1969,7 +1979,7 @@ bool ht_aviewer::symbol_handler(eval_scalar *result, char *name)
 		if (l) {
 			w=l->location->addr;
 			uint64 b;
-			w->putIntoArray((byte*)&b);
+			w->putIntoUInt64(b);
 			scalar_create_int_q(result, b);
 			return true;
 		}
@@ -1981,13 +1991,7 @@ bool ht_aviewer::qword_to_pos(uint64 q, viewer_pos *pos)
 {
 	if (!analy) return false;
 	Address *a=analy->createAddress();
-	// FIXME: this is just plain wrong!!
-	if (a->byteSize()==8) {
-		a->getFromArray((byte*)&q);
-	} else {
-		uint32 ii = q;
-		a->getFromArray((byte*)&ii);
-	}
+	a->getFromUInt64(q);
 	if (analy->validAddress(a, scvalid)) {
 		bool res = convertAddressToViewerPos(a, pos);
 		delete a;
@@ -2045,15 +2049,18 @@ bool ht_analy_sub::convert_ofs_to_id(const FileOfs offset, LINE_ID *line_id)
 void	ht_analy_sub::first_line_id(LINE_ID *line_id)
 {
 	clear_line_id(line_id);
-	lowestaddress->putIntoArray((byte*)&(line_id->id2));
+	uint64 u;
+	lowestaddress->putIntoUInt64(u);
+	line_id->id1 = u >> 32;
+	line_id->id2 = u;
 }
 
-bool ht_analy_sub::getline(char *line, const LINE_ID line_id)
+bool ht_analy_sub::getline(char *line, int maxlen, const LINE_ID line_id)
 {
 	if (!analy) return false;
 	Address *a = analy->createAddress();
-	a->getFromArray((byte*)&(line_id.id2));
-	bool res = output->getLineString(line, 1024, a, (int)line_id.id1);
+	a->getFromUInt64((uint64(line_id.id1) << 32) + line_id.id2);
+	bool res = output->getLineString(line, maxlen, a, (int)line_id.id3);
 	delete a;
 	return res;
 }
@@ -2061,19 +2068,25 @@ bool ht_analy_sub::getline(char *line, const LINE_ID line_id)
 void	ht_analy_sub::last_line_id(LINE_ID *line_id)
 {
 	clear_line_id(line_id);
-	highestaddress->putIntoArray((byte*)&(line_id->id2));
+	uint64 u;
+	highestaddress->putIntoUInt64(u);
+	line_id->id1 = u >> 32;
+	line_id->id2 = u;
 }
 
 int ht_analy_sub::next_line_id(LINE_ID *line_id, int n)
 {
 	if (!analy) return false;
 	Address *a = analy->createAddress();
-	a->getFromArray((byte*)&(line_id->id2));
-	int line = line_id->id1;
+	a->getFromUInt64((uint64(line_id->id1) << 32) + line_id->id2);
+	int line = line_id->id3;
 	int res = output->nextLine(a, line, n, highestaddress);
 	if (res) {
-		line_id->id1 = line;
-		a->putIntoArray((byte*)&(line_id->id2));
+		line_id->id3 = line;
+		uint64 u;
+		a->putIntoUInt64(u);
+		line_id->id1 = u >> 32;
+		line_id->id2 = u;
 	}
 	delete a;
 	return res;
@@ -2083,12 +2096,15 @@ int ht_analy_sub::prev_line_id(LINE_ID *line_id, int n)
 {
 	if (!analy) return false;
 	Address *a = analy->createAddress();
-	a->getFromArray((byte*)&(line_id->id2));
-	int line = line_id->id1;
+	a->getFromUInt64((uint64(line_id->id1) << 32) + line_id->id2);
+	int line = line_id->id3;
 	int res = output->prevLine(a, line, n, lowestaddress);
 	if (res) {
-		line_id->id1 = line;
-		a->putIntoArray((byte*)&(line_id->id2));
+		line_id->id3 = line;
+		uint64 u;
+		a->putIntoUInt64(u);
+		line_id->id1 = u >> 32;
+		line_id->id2 = u;
 	}
 	delete a;
 	return res;
@@ -2131,5 +2147,3 @@ void	ht_analy_sub::setAnalyser(Analyser *Analy)
 	output->analy = Analy;
 	output->invalidateCache();
 }
-
-
