@@ -25,9 +25,9 @@ char *globalerror = sglobalerror;
 
 ht_view *app;
 ht_view *baseview;
-screendrawbuf *screen;
+SystemDisplay *screen;
 char appname[HT_NAME_MAX+1];
-ht_list *virtual_fs_list;
+List *virtual_fs_list;
 void *project;
 int some_analyser_active = 0;
 int num_ops_parsed = 0;
