@@ -314,7 +314,7 @@ protected:
 			LINE_ID id;
 		} cursor_tag_id;
 //	};
-	char cursor_line[1024];	/* FIXME: possible buffer overflow ! */
+	char cursor_line[1024];
 /* tag palettes */
 	palette tagpal;
 /**/
@@ -438,7 +438,7 @@ public:
 	virtual	bool convert_id_to_ofs(const LINE_ID line_id, FileOfs *offset);
 	virtual	bool closest_line_id(LINE_ID *line_id);
 	virtual	void first_line_id(LINE_ID *line_id);
-	virtual	bool getline(char *line, const LINE_ID line_id);
+	virtual	bool getline(char *line, int maxlen, const LINE_ID line_id);
 	virtual	void handlemsg(htmsg *msg);
 	virtual	void last_line_id(LINE_ID *line_id);
 	virtual	int next_line_id(LINE_ID *line_id, int n);
@@ -481,7 +481,7 @@ public:
 	virtual	bool convert_ofs_to_id(const FileOfs offset, LINE_ID *line_id);
 	virtual	bool convert_id_to_ofs(const LINE_ID line_id, FileOfs *offset);
 	virtual	void first_line_id(LINE_ID *line_id);
-	virtual	bool getline(char *line, const LINE_ID line_id);
+	virtual	bool getline(char *line, int maxlen, const LINE_ID line_id);
 	virtual	void last_line_id(LINE_ID *line_id);
 	virtual	int next_line_id(LINE_ID *line_id, int n);
 	virtual	int prev_line_id(LINE_ID *line_id, int n);
@@ -506,7 +506,7 @@ public:
 		void init(File *file, uint uid);
 /* overwritten */
 	virtual	void first_line_id(LINE_ID *line_id);
-	virtual	bool getline(char *line, const LINE_ID line_id);
+	virtual	bool getline(char *line, int maxlen, const LINE_ID line_id);
 	virtual	void last_line_id(LINE_ID *line_id);
 	virtual	int next_line_id(LINE_ID *line_id, int n);
 	virtual	int prev_line_id(LINE_ID *line_id, int n);
@@ -534,7 +534,7 @@ public:
 	virtual	bool convert_id_to_ofs(const LINE_ID line_id, FileOfs *offset);
 	virtual	bool closest_line_id(LINE_ID *line_id);
 	virtual	void first_line_id(LINE_ID *line_id);
-	virtual	bool getline(char *line, const LINE_ID line_id);
+	virtual	bool getline(char *line, int maxlen, const LINE_ID line_id);
 	virtual	void handlemsg(htmsg *msg);
 	virtual	void last_line_id(LINE_ID *line_id);
 	virtual	int next_line_id(LINE_ID *line_id, int n);
@@ -560,7 +560,7 @@ public:
 	virtual	bool convert_ofs_to_id(const FileOfs offset, LINE_ID *line_id);
 	virtual	bool convert_id_to_ofs(const LINE_ID line_id, FileOfs *offset);
 	virtual	void first_line_id(LINE_ID *line_id);
-	virtual	bool getline(char *line, const LINE_ID line_id);
+	virtual	bool getline(char *line, int maxlen, const LINE_ID line_id);
 	virtual	void last_line_id(LINE_ID *line_id);
 	virtual	int next_line_id(LINE_ID *line_id, int n);
 	virtual	int prev_line_id(LINE_ID *line_id, int n);
@@ -582,7 +582,7 @@ public:
 	virtual	bool convert_ofs_to_id(const FileOfs offset, LINE_ID *line_id);
 	virtual	bool convert_id_to_ofs(const LINE_ID line_id, FileOfs *offset);
 	virtual	void first_line_id(LINE_ID *line_id);
-	virtual	bool getline(char *line, const LINE_ID line_id);
+	virtual	bool getline(char *line, int maxlen, const LINE_ID line_id);
 	virtual	void handlemsg(htmsg *msg);
 	virtual	void last_line_id(LINE_ID *line_id);
 	virtual	int next_line_id(LINE_ID *line_id, int n);
