@@ -123,6 +123,7 @@ void	AnalyserOutput::init(Analyser *Analy)
 	current_time = 0;
 	work_buffer_start = ht_malloc(WORKBUF_LEN);
 	work_buffer = work_buffer_start;
+	work_buffer_end = work_buffer_start + WORKBUF_LEN - 1;
 	temp_buffer = ht_malloc(WORKBUF_LEN);
 	dis_style = DIS_STYLE_HIGHLIGHT+DIS_STYLE_HEX_NOZEROPAD+DIS_STYLE_HEX_ASMSTYLE+X86DIS_STYLE_OPTIMIZE_ADDR;
 	changeConfig();
@@ -262,18 +263,9 @@ void AnalyserOutput::generateAddr(Address *Addr, OutAddr *oa)
 				char b[32];
 				sprintf(b, "<< show xrefs (%d) >>", xref_count);
 				char *t;
-				if (Addr->byteSize()==4) {
-					uint32 d;
-					Addr->putIntoArray((byte*)&d);
-					t = externalLink(b, d, 0, 0, 1, NULL);
-				} else {
-					struct {
-						uint32 a PACKED;
-						uint32 b PACKED;
-					} d;
-					Addr->putIntoArray((byte*)&d);
-					t = externalLink(b, d.a, d.b, 0, 1, NULL);
-				}
+				uint64 u;
+				Addr->putIntoUInt64(u);
+				t = externalLink(b, u >> 32, u, 0, 1, NULL);				
 				write(t);
 			} else {
 				Container *xr = cur_addr->xrefs;
@@ -386,7 +378,7 @@ void AnalyserOutput::generateAddr(Address *Addr, OutAddr *oa)
 			} else {
 				putElement(ELEMENT_TYPE_HIGHLIGHT_DATA_CODE, "db          ??");
 			}
-			bytes_line++;
+			bytes_line = want_bytes_line = 1;
 		}
 		
 	} else {
@@ -397,7 +389,7 @@ void AnalyserOutput::generateAddr(Address *Addr, OutAddr *oa)
 			&& (cur_addr->type.type != dt_code)) {
 				switch (cur_addr->type.type) {
 					case dt_int: {
-						bytes_line += cur_addr->type.length;
+						bytes_line = want_bytes_line = cur_addr->type.length;
 						assert(cur_addr->type.length);
 						if (analy->validAddress(addr, scinitialized)) {
 							char buf[50];
@@ -467,7 +459,7 @@ void AnalyserOutput::generateAddr(Address *Addr, OutAddr *oa)
 								b = buf + 16 + escape_special(buf+16, 100, bufread, r, "\"", false);
 								*b = '\"'; b++; *b = 0;
 								putElement(ELEMENT_TYPE_HIGHLIGHT_DATA_CODE, buf);
-								bytes_line += cur_addr->type.length;
+								bytes_line = want_bytes_line = cur_addr->type.length;
 								break;
 							}
 							default: {assert(0);}
@@ -483,7 +475,7 @@ void AnalyserOutput::generateAddr(Address *Addr, OutAddr *oa)
 				}
 			} else {
 				// not a known address
-				bytes_line++;
+				bytes_line = want_bytes_line = 1;
 				byte c;
 				if (analy->validAddress(addr, scinitialized) && (analy->bufPtr(addr, &c, 1)==1)) {
 					char buf[20];
@@ -505,7 +497,7 @@ void AnalyserOutput::generateAddr(Address *Addr, OutAddr *oa)
 				sprintf(buf, "db          ?? * %d", d);
 				putElement(ELEMENT_TYPE_HIGHLIGHT_DATA_CODE, buf);
 			} else {
-				bytes_line += 1;
+				bytes_line = want_bytes_line = 1;
 				putElement(ELEMENT_TYPE_HIGHLIGHT_DATA_CODE, "db          ??");
 			}
 		}
@@ -528,7 +520,7 @@ int	AnalyserOutput::generateFile(Address *from, Address *to)
 	if (!out) return OUTPUT_GENERATE_ERR_INVAL;
 	header();
 	int line = 0;
-	int len;
+	int len = 0;
 	while (from->compareTo(to) <= 0) {
 		char buffer[1024];
 		if (getLineString(buffer, sizeof buffer, from, line)) {
@@ -537,12 +529,13 @@ int	AnalyserOutput::generateFile(Address *from, Address *to)
 			if (out->write(buffer, wr) != wr) return OUTPUT_GENERATE_ERR_STREAM;
 			
 			int tmplen;
-			if (getLineByteLength(len, from, line)) {
+			if (getLineByteLength(tmplen, from, line)) {
 				len += tmplen;
 			}
 			line++;
 		} else {
 			from->add(len);
+			len = 0;
 			line = 0;
 		}
 	}
@@ -571,6 +564,7 @@ OutAddr *AnalyserOutput::getAddr(Address *Addr)
 			DPRINTF("generate\n");
 			if (out_addrs->count() > 1024) {
 				reset();
+				delete addr;
 				addr = Addr->clone();
 			}
 			oa = new OutAddr(Addr, current_time);
@@ -689,7 +683,7 @@ int	AnalyserOutput::prevLine(Address *&Addr, int &line, int n, Address *min)
 {
 //	fprintf(stdout, "prev_line(%x, %d, %d)\n", *Addr, *line, n);
 //#undef DPRINTF2
-//#define DPRINTF2(msg...) {ht_snprintf(tbuf, 1024, ##msg); fprintf(stderr, "%s", tbuf);}
+//#define DPRINTF2(msg...) {ht_snprintf(tbuf, 1024, msg); fprintf(stderr, "%s", tbuf);}
 //	char tbuf[1024];
 	DPRINTF2("prev_line(%y, %d, %d, %y)\n", Addr, line, n, min);
 
@@ -746,6 +740,7 @@ int	AnalyserOutput::prevLine(Address *&Addr, int &line, int n, Address *min)
 		delete search_addr;
 		search_addr = min->clone();
 	}
+	DPRINTF2("search-start: %y\n", search_addr);
 
 	/*
 	 *	|prev| contains the previous "logical" location.
@@ -753,13 +748,14 @@ int	AnalyserOutput::prevLine(Address *&Addr, int &line, int n, Address *min)
 	 */
 	Location *prev = analy->enumLocationsReverse(Addr);
 	if (prev) {
+		DPRINTF2("prev: %y\n", prev->addr);
 		/*
 		 *	|prevnext| contains the "end address" of |prev|.
 		 *	So we know how long (how much bytes) prev is.
 		 */
 		Address *prevnext = prev->addr->clone();
 		if (prevnext->add(getAddrByteLength(prev->addr))) {
-			DPRINTF2("mid-test\n");
+			DPRINTF2("mid-test: prevnext %y\n", prevnext);
 			if (prevnext->compareTo(Addr) > 0) {
 				/*
 				 *   We were in the middle of a location.
