@@ -86,7 +86,7 @@ void Stream::addEventListener(StreamEventListener *l, StreamEvent mask)
 */
 void Stream::checkAccess(IOAccessMode mask)
 {
-	if (mAccessMode & mask != mask) throw IOException(EACCES);
+	if ((mAccessMode & mask) != mask) throw IOException(EACCES);
 }
 
 /**
@@ -787,6 +787,9 @@ char *File::fgetstrz()
 				break;
 			}
 		}
+		if (s < 64) {
+			break;
+		}
 	}
 	/* read string */
 	char *str = ht_malloc(z);
